@@ -2,44 +2,49 @@ import numpy as np
 from scipy.sparse import csc_matrix
 from numba import jit
 
-try:
-    from . import specialhoppingf90
-#    raise
-    use_fortran=True
-except:
-    use_fortran=False
-#    print("FORTRAN not working in specialhopping")
+#try:
+#    from . import specialhoppingf90
+##    raise
+#    use_fortran=True
+#except:
+#    use_fortran=False
 use_fortran=False
 
 
+def obj2callable(a):
+    if callable(a): return a # input is a function
+    else: return lambda x: a # input is a number
+
+
 
 def twisted(cutoff=5.0,ti=0.3,lambi=8.0,
         lamb=12.0,dl=3.0,lambz=10.0,b=0.0,phi=0.0):
   """Hopping for twisted bilayer graphene"""
+  ti = obj2callable(ti) # convert to callable
   cutoff2 = cutoff**2 # cutoff in distance
   def fun(r1,r2):
-    rr = (r1-r2) # distance
-    rr = rr.dot(rr) # distance
-    if rr>cutoff2: return 0.0 # too far
-    if rr<0.001: return 0.0 # same atom
-    dx = r1[0]-r2[0]
-    dy = r1[1]-r2[1]
-    dz = r1[2]-r2[2]
-    r = np.sqrt(rr)
-#    if r2>100.0: return 0.0 # too far
-    if (r-1.0)<-0.1: 
-      raise
-    out = -(dx*dx + dy*dy)/rr*np.exp(-lamb*(r-1.0))*np.exp(-lambz*dz*dz)
-    out += -ti*(dz*dz)/rr*np.exp(-lambi*(r-dl))
-    #### fix for magnetic field
-    cphi = np.cos(phi*np.pi)
-    sphi = np.sin(phi*np.pi)
-    r = (r1+r2)/2.
-    dr = r1-r2
-    p = 2*r[2]*(dr[0]*sphi - dr[1]*cphi)
-    out *= np.exp(1j*b*p)
-    #####
-    return out
+      rr = (r1-r2) # distance
+      rm  = (r1+r2)/2. # average location
+      rr = rr.dot(rr) # distance
+      if rr>cutoff2: return 0.0 # too far
+      if rr<0.001: return 0.0 # same atom
+      dx = r1[0]-r2[0]
+      dy = r1[1]-r2[1]
+      dz = r1[2]-r2[2]
+      r = np.sqrt(rr)
+      if (r-1.0)<-0.1: raise
+      out = -(dx*dx + dy*dy)/rr*np.exp(-lamb*(r-1.0))*np.exp(-lambz*dz*dz)
+      # interlayer hopping
+      out += -ti(rm)*(dz*dz)/rr*np.exp(-lambi*(r-dl))
+      #### fix for magnetic field
+#      cphi = np.cos(phi*np.pi)
+#      sphi = np.sin(phi*np.pi)
+#      r = (r1+r2)/2.
+#      dr = r1-r2
+#      p = 2*r[2]*(dr[0]*sphi - dr[1]*cphi)
+#      out *= np.exp(1j*b*p)
+      #####
+      return out
   return fun
 
 
@@ -63,19 +68,14 @@ def twisted_matrix(cutoff=5.0,ti=0.3,lambi=8.0,mint=1e-5,
       return out
     return funhop # return function
   else:
-    print("Using Python function in twisted")
-    return twisted_matrix_python(cutoff=cutoff,ti=ti,mint=mint,
+      if callable(ti): # workaround for callable interlayer hopping
+          tij = twisted(cutoff=cutoff,ti=ti,
+                          lambi=lambi,lamb=lamb,dl=dl,lambz=lambz)
+          return entry2matrix(tij)
+      else: # conventional JIT function
+          return twisted_matrix_python(cutoff=cutoff,ti=ti,mint=mint,
                                   lambi=lambi,lamb=lamb,lambz=lambz,
                                   dl=dl,**kwargs)
-#    def funhop(r1,r2):
-#      fh = twisted(cutoff=cutoff,ti=ti,lambi=lambi,lamb=lamb,dl=dl,**kwargs)
-#      m = np.array([[fh(r1i,r2j) for r1i in r1] for r2j in r2],dtype=np.complex)
-#      m = csc_matrix(m,dtype=np.complex).T
-#      m.eliminate_zeros()
-#      return m
-#  return funhop # function
-
-
 
 
 def multilayer(ti=0.3,dz=3.0):
@@ -101,10 +101,10 @@ def phase_C3_matrix(*args,**kwargs):
 
 
 def phase_C3(g,phi=0.5,t=1.0,d=1.0):
-    """Create a fucntion that computes hoppings that alternate
+    """Create a function that computes hoppings that alternate
     between +\phi and -\phi every 60 degrees"""
     if len(g.r)==1:
-      g = g.supercell(2) # create a supercell
+      g = g.get_supercell(2) # create a supercell
     ds = g.get_connections()
     i = 0 # first site
     j = ds[i][0] # connected site
@@ -181,47 +181,74 @@ def strained_hopping_matrix(*args,**kwargs):
     return entry2matrix(f) # return the matrix
 
 
+from .algebra import isnumber
 
 class HoppingGenerator():
     """Class for a Hopping generator"""
     def __init__(self,m):
         if type(m)==HoppingGenerator: self.f = m.f # redefine
         elif callable(m): self.f = m # define callable function
+        else: raise
     def __call__(self,rs1,rs2):
         """Call method"""
         return self.f(rs1,rs2)
     def __mul__(self,m):
-        m2 = HoppingGenerator(m) # transform to HoppingGenerator
-        fout = lambda rs1,rs2: np.array(self(rs1,rs2))*np.array(m2(rs1,rs2))
+        if isnumber(m): # number input 
+            fout = lambda rs1,rs2: np.array(m*np.array(self(rs1,rs2)))
+        else: # anything else
+            m2 = HoppingGenerator(m) # transform to HoppingGenerator
+            fout = lambda rs1,rs2: np.array(self(rs1,rs2))*np.array(m2(rs1,rs2))
         return HoppingGenerator(fout) # return new object
     def __rmul__(self,m): return self*m # commutative 
+    def __radd__(self,m): return self + m # commutative 
+    def __add__(self,m):  
+        m2 = HoppingGenerator(m) # transform to HoppingGenerator
+        fout = lambda rs1,rs2: np.array(self(rs1,rs2)) + np.array(m2(rs1,rs2))
+        return HoppingGenerator(fout) # return new object
+    def __neg__(self): return (-1)*self # minus
+    def __sub__(self,a): return self + (-1)*a # minus
+    def copy(self):
+        from copy import deepcopy
+        return deepcopy(self)
+    def apply(self,f):
+        """Given a certain function of the position, 
+        apply it to all the hoppings"""
+        def fm(rs1,rs2): # define a new function
+            m = self.f(rs1,rs2) # get the matrix
+            p = np.array([[f((r1+r2)/2.) for r1 in rs1] for r2 in rs2])
+            return m*p # return product
+        return HoppingGenerator(fm) # new generator
+
+
 
 
 def twisted_matrix_python(cutoff=10,**kwargs):
   """Function returning the hopping of a twisted matrix"""
   def tij(rs1,rs2): # function to return
-    nr = len(rs1) # length
-    nmax = nr*int(10*cutoff**2) # maximum number of hoppings
-    data = np.zeros(nmax,dtype=np.complex) # data
-    ii = np.zeros(nmax,dtype=int) # index
-    jj = np.zeros(nmax,dtype=int) # index
-    ii,jj,data,nk = twisted_matrix_jit(np.array(rs1),np.array(rs2),ii,jj,data,cutoff=cutoff,**kwargs) # call function
-    if nk>nmax: raise # sanity check
-    ii = ii[0:nk] # only nonzero
-    jj = jj[0:nk] # only nonzero
-    data = data[0:nk] # only nonzero
-    out = csc_matrix((data,(ii,jj)),shape=(nr,nr),dtype=np.complex) # matrix
-    out.eliminate_zeros()
-    return out
+      nr = len(rs1) # length
+      nmax = nr*int(10*cutoff**2) # maximum number of hoppings
+      data = np.zeros(nmax,dtype=np.complex) # data
+      ii = np.zeros(nmax,dtype=int) # index
+      jj = np.zeros(nmax,dtype=int) # index
+      ii,jj,data,nk = twisted_matrix_jit(np.array(rs1),np.array(rs2),
+                         ii,jj,data,cutoff=cutoff,**kwargs) # call function
+      if nk>nmax: raise # sanity check
+      ii = ii[0:nk] # only nonzero
+      jj = jj[0:nk] # only nonzero
+      data = data[0:nk] # only nonzero
+      out = csc_matrix((data,(ii,jj)),shape=(nr,nr),dtype=np.complex) # matrix
+      out.eliminate_zeros()
+      return out
   return tij
     
 
 
 @jit(nopython=True)
 def twisted_matrix_jit(rs1,rs2,ii,jj,data,cutoff=5.0,ti=0.3,lambi=8.0,
-        mint = 1e-5,
+        mint = 1e-5,t=1.0,
         lamb=12.0,dl=3.0,lambz=10.0):
-  """Hopping for twisted bilayer graphene, returning the indexes of a sparse matrix"""
+  """Hopping for twisted bilayer graphene, returning the indexes of a 
+  sparse matrix"""
   cutoff2 = cutoff**2 # cutoff in distance
   ik = 0 # counter
   for i1 in range(len(rs1)):
@@ -239,7 +266,7 @@ def twisted_matrix_jit(rs1,rs2,ii,jj,data,cutoff=5.0,ti=0.3,lambi=8.0,
   #    if r2>100.0: return 0.0 # too far
       if (r-1.0)<-0.1:
         raise
-      out = -(dx*dx + dy*dy)/rr*np.exp(-lamb*(r-1.0))*np.exp(-lambz*dz*dz)
+      out = -t*(dx*dx + dy*dy)/rr*np.exp(-lamb*(r-1.0))*np.exp(-lambz*dz*dz)
       out += -ti*(dz*dz)/rr*np.exp(-lambi*(r-dl))
       #### fix for magnetic field
 #      cphi = np.cos(phi*np.pi)
@@ -256,3 +283,26 @@ def twisted_matrix_jit(rs1,rs2,ii,jj,data,cutoff=5.0,ti=0.3,lambi=8.0,
         ik += 1 # increase counter
   return ii,jj,data,ik
 
+
+
+
+
+def NNG(g,ts):
+    """Hopping generator for nearest neighbor hoppings
+    - g: geometry
+    - ts: hoppings for each neighbor
+    """
+    fm = neighbor_hopping_matrix(g,ts) # get the function
+    return HoppingGenerator(fm) # return a generator 
+
+def ILG(g,ti,**kwargs):
+    """Generator for an interlayer hopping using an exponential
+    parametrization
+    - g: geometry
+    - ti: interlayer hopping
+    - **kawrgs: optional arguments for twisted hopping
+    """
+    fm = twisted_matrix(t=0.,ti=-ti,**kwargs) # interlayer hopping generator
+    # return a generator
+    from . import algebra
+    return HoppingGenerator(lambda *args: algebra.todense(fm(*args))) 
